##  Branches
SBOMs are ingested as build artifacts from the branches you configure in the integration. You can use both the default branch and other branches for this purpose.
  * Default branch: This is the repository's default branch, which is set in the repository settings to a branch such as master, main, or develop. By default, SBOMs are ingested from this branch without requiring additional configuration.
  * Other branches: You can specify particular branch names or define rules for branch naming, such as those that start with release or contain version. In this scenario, SBOMs are ingested from all branches that match the specified criteria.
